@@ -25,12 +25,12 @@ class CsrDeviceHandler(DefaultDeviceHandler):
     Cisco CSR handler for device specific information.
 
     """
-    def __init__(self, device_params):
+    def __init__(self, device_params, ignore_errors=None):
         warn(
             'CsrDeviceHandler is deprecated, please use IosxeDeviceHandler',
             DeprecationWarning,
             stacklevel=2)
-        super(CsrDeviceHandler, self).__init__(device_params)
+        super(CsrDeviceHandler, self).__init__(device_params, ignore_errors)
 
     def add_additional_ssh_connect_params(self, kwargs):
         warn(
