@@ -24,8 +24,8 @@ class IosxrDeviceHandler(DefaultDeviceHandler):
     Cisco IOS-XR handler for device specific information.
 
     """
-    def __init__(self, device_params):
-        super(IosxrDeviceHandler, self).__init__(device_params)
+    def __init__(self, device_params, ignore_errors=None):
+        super(IosxrDeviceHandler, self).__init__(device_params, ignore_errors)
 
     def add_additional_ssh_connect_params(self, kwargs):
         kwargs['unknown_host_cb'] = iosxr_unknown_host_cb
