@@ -17,11 +17,11 @@ import base64
 import getpass
 import os
 import re
-import six
 import sys
 import socket
 import threading
 from binascii import hexlify
+from io import BytesIO as StringIO
 
 try:
     import selectors
@@ -77,12 +77,6 @@ def _colonify(fp):
     return finga
 
 
-if sys.version < '3':
-    from six import StringIO
-else:
-    from io import BytesIO as StringIO
-
-
 class SSHSession(Session):
 
     "Implements a :rfc:`4742` NETCONF session over SSH."
@@ -263,7 +257,7 @@ class SSHSession(Session):
             proxycommand = config.get("proxycommand")
             if proxycommand:
                 self.logger.debug("Configuring Proxy. %s", proxycommand)
-                if not isinstance(proxycommand, six.string_types):
+                if not isinstance(proxycommand, str):
                   proxycommand = [os.path.expanduser(elem) for elem in proxycommand]
                 else:
                   proxycommand = os.path.expanduser(proxycommand)
@@ -287,11 +281,7 @@ class SSHSession(Session):
                 else:
                     raise SSHError("Could not open socket to %s:%s" % (host, port))
         elif sock is None:
-            if sys.version_info[0] < 3:
-                s = socket.fromfd(int(sock_fd), socket.AF_INET, socket.SOCK_STREAM)
-                sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM, _sock=s)
-            else:
-                sock = socket.fromfd(int(sock_fd), socket.AF_INET, socket.SOCK_STREAM)
+            sock = socket.fromfd(int(sock_fd), socket.AF_INET, socket.SOCK_STREAM)
             sock.settimeout(timeout)
 
         self._transport = paramiko.Transport(sock)
@@ -406,17 +396,16 @@ class SSHSession(Session):
         saved_exception = None
 
         for key_filename in key_filenames:
-            for cls in (paramiko.RSAKey, paramiko.DSSKey, paramiko.ECDSAKey, paramiko.Ed25519Key):
-                try:
-                    key = cls.from_private_key_file(key_filename, password)
-                    self.logger.debug("Trying key %s from %s",
-                                      hexlify(key.get_fingerprint()),
-                                      key_filename)
-                    self._transport.auth_publickey(username, key)
-                    return
-                except Exception as e:
-                    saved_exception = e
-                    self.logger.debug(e)
+            try:
+                key = paramiko.PKey.from_path(key_filename, password.encode("utf-8"))
+                self.logger.debug("Trying key %s from %s",
+                                  hexlify(key.get_fingerprint()),
+                                  key_filename)
+                self._transport.auth_publickey(username, key)
+                return
+            except Exception as e:
+                saved_exception = e
+                self.logger.debug(e)
 
         if allow_agent:
             # resequence keys from agent using private key names
@@ -453,26 +442,32 @@ class SSHSession(Session):
             rsa_key = os.path.expanduser("~/.ssh/id_rsa")
             dsa_key = os.path.expanduser("~/.ssh/id_dsa")
             ecdsa_key = os.path.expanduser("~/.ssh/id_ecdsa")
+            ed25519_key = os.path.expanduser("~/.ssh/id_ed25519")
             if os.path.isfile(rsa_key):
-                keyfiles.append((paramiko.RSAKey, rsa_key))
+                keyfiles.append(rsa_key)
             if os.path.isfile(dsa_key):
-                keyfiles.append((paramiko.DSSKey, dsa_key))
+                keyfiles.append(dsa_key)
             if os.path.isfile(ecdsa_key):
-                keyfiles.append((paramiko.ECDSAKey, ecdsa_key))
+                keyfiles.append(ecdsa_key)
+            if os.path.isfile(ed25519_key):
+                keyfiles.append(ed25519_key)
             # look in ~/ssh/ for windows users:
             rsa_key = os.path.expanduser("~/ssh/id_rsa")
             dsa_key = os.path.expanduser("~/ssh/id_dsa")
             ecdsa_key = os.path.expanduser("~/ssh/id_ecdsa")
+            ed25519_key = os.path.expanduser("~/ssh/id_ed25519")
             if os.path.isfile(rsa_key):
-                keyfiles.append((paramiko.RSAKey, rsa_key))
+                keyfiles.append(rsa_key)
             if os.path.isfile(dsa_key):
-                keyfiles.append((paramiko.DSSKey, dsa_key))
+                keyfiles.append(dsa_key)
             if os.path.isfile(ecdsa_key):
-                keyfiles.append((paramiko.ECDSAKey, ecdsa_key))
+                keyfiles.append(ecdsa_key)
+            if os.path.isfile(ed25519_key):
+                keyfiles.append(ed25519_key)
 
-        for cls, filename in keyfiles:
+        for filename in keyfiles:
             try:
-                key = cls.from_private_key_file(filename, password)
+                key = paramiko.PKey.from_path(filename, password.encode("utf-8"))
                 self.logger.debug("Trying discovered key %s in %s",
                                   hexlify(key.get_fingerprint()), filename)
                 self._transport.auth_publickey(username, key)
