@@ -17,11 +17,9 @@
 
 
 import io
-import sys
-import six
 import types
-from six import StringIO
-from io import BytesIO
+from io import BytesIO, StringIO
+
 from lxml import etree
 
 # In case issues come up with XML generation/parsing
@@ -91,7 +89,7 @@ except AttributeError:
         # cElementTree uses ElementTree's _namespace_map, so that's ok
         ElementTree._namespace_map[uri] = prefix
 
-for (ns, pre) in six.iteritems({
+for (ns, pre) in {
     BASE_NS_1_0: 'nc',
     NETCONF_MONITORING_NS: 'ncm',
     NXOS_1_0: 'nxos',
@@ -101,7 +99,7 @@ for (ns, pre) in six.iteritems({
     CISCO_CPI_1_0: 'cpi',
     FLOWMON_1_0: 'fm',
     JUNIPER_1_1: 'junos',
-}):
+}.items():
     register_namespace(pre, ns)
 
 qualify = lambda tag, ns=BASE_NS_1_0: tag if ns is None else "{%s}%s" % (ns, tag)
@@ -111,11 +109,8 @@ qualify = lambda tag, ns=BASE_NS_1_0: tag if ns is None else "{%s}%s" % (ns, tag
 def to_xml(ele, encoding="UTF-8", pretty_print=False):
     "Convert and return the XML for an *ele* (:class:`~xml.etree.ElementTree.Element`) with specified *encoding*."
     xml = etree.tostring(ele, encoding=encoding, pretty_print=pretty_print)
-    if sys.version < '3':
-        return xml if xml.startswith('<?xml') else '<?xml version="1.0" encoding="%s"?>%s' % (encoding, xml)
-    else:
-        return xml.decode('UTF-8') if xml.startswith(b'<?xml') \
-            else '<?xml version="1.0" encoding="%s"?>%s' % (encoding, xml.decode('UTF-8'))
+    return xml.decode('UTF-8') if xml.startswith(b'<?xml') \
+        else '<?xml version="1.0" encoding="%s"?>%s' % (encoding, xml.decode('UTF-8'))
 
 
 def to_ele(x, huge_tree=False):
@@ -123,18 +118,12 @@ def to_ele(x, huge_tree=False):
 
     *huge_tree*: parse XML with very deep trees and very long text content
     """
-    if sys.version < '3':
-        return x if etree.iselement(x) else etree.fromstring(x, parser=_get_parser(huge_tree))
-    else:
-        return x if etree.iselement(x) else etree.fromstring(x.encode('UTF-8'), parser=_get_parser(huge_tree))
+    return x if etree.iselement(x) else etree.fromstring(x.encode('UTF-8'), parser=_get_parser(huge_tree))
 
 
 def parse_root(raw):
     "Efficiently parses the root element of a *raw* XML document, returning a tuple of its qualified name and attribute dictionary."
-    if sys.version < '3':
-        fp = StringIO(raw)
-    else:
-        fp = BytesIO(raw.encode('UTF-8'))
+    fp = BytesIO(raw.encode('UTF-8'))
     for event, element in etree.iterparse(fp, events=('start',)):
         return (element.tag, element.attrib)
 
@@ -168,7 +157,7 @@ XPATH_NAMESPACES = {
 }
 
 
-class NCElement(object):
+class NCElement:
     def __init__(self, result, transform_reply, huge_tree=False):
         self.__result = result
         self.__transform_reply = transform_reply
@@ -213,10 +202,7 @@ class NCElement(object):
 
     def __str__(self):
         """syntactic sugar for str() - alias to tostring"""
-        if sys.version < '3':
-            return self.tostring
-        else:
-            return self.tostring.decode('UTF-8')
+        return self.tostring.decode('UTF-8')
 
     @property
     def tostring(self):
