@@ -1,9 +1,11 @@
-from ncclient.operations.retrieve import *
+import copy
 import unittest
-try:
-    from unittest.mock import patch  # Python 3.4 and later
-except ImportError:
-    from mock import patch
+from unittest.mock import patch
+
+from xml.etree import ElementTree
+from lxml import etree
+
+from ncclient.operations.retrieve import *
 from ncclient import manager
 import ncclient.manager
 import ncclient.transport
@@ -11,10 +13,6 @@ from ncclient.capabilities import Capabilities
 from ncclient.xml_ import *
 from ncclient.operations import RaiseMode
 from ncclient.operations.errors import MissingCapabilityError
-from xml.etree import ElementTree
-from lxml import etree
-import copy
-import six
 
 
 class TestRetrieve(unittest.TestCase):
@@ -96,8 +94,7 @@ class TestRetrieve(unittest.TestCase):
             "Invalid 'with-defaults' mode 'report-all-tagged'; the server "
             "only supports the following: explicit, report-all, trim"
         )
-        six.assertRaisesRegex(
-            self,
+        self.assertRaisesRegex(
             WithDefaultsError,
             expected_error,
             obj.request,
